@@ -107,9 +107,16 @@ class ACEye():
         self.all_files(parsed_json) 
         parsed_json = json.dumps(self.cluster_health(), indent=4, sort_keys=True)
         self.all_files(parsed_json) 
+        parsed_json = json.dumps(self.device_packages(), indent=4, sort_keys=True)
+        self.all_files(parsed_json) 
+        parsed_json = json.dumps(self.aggregate_interfaces(), indent=4, sort_keys=True)
+        self.all_files(parsed_json)
+        parsed_json = json.dumps(self.l3_interfaces(), indent=4, sort_keys=True)
+        self.all_files(parsed_json)
 
     def make_directories(self):
-        api_list = ['Application Profiles',
+        api_list = ['Aggregate Interfaces',
+                    'Application Profiles',
                     'Attachable Access Entity Profiles',
                     'Audit Log',
                     'BGP Route Reflectors',
@@ -118,6 +125,7 @@ class ACEye():
                     'Contexts',
                     'Contracts',
                     'Contract Subjects',
+                    'Device Packages',
                     'Endpoints',
                     'EPG',
                     'Events',
@@ -135,6 +143,7 @@ class ACEye():
                     'License Entitlements',
                     'L2Outs',
                     'L3 Domains',
+                    'L3 Interfaces',
                     'L3Outs',
                     'Leaf Interface Profiles',
                     'Leaf Switch Profiles',
@@ -504,6 +513,27 @@ class ACEye():
         response_dict  = response.json()
         return(response_dict)
 
+    def device_packages(self):
+        self.url = f"{ self.aci }/api/node/class/vnsMDev.json"
+        response = requests.request("GET", self.url, cookies = self.cookie, verify=False)
+        print(f"<Device Packages code { response.status_code } for { self.url }>")
+        response_dict  = response.json()
+        return(response_dict)
+
+    def aggregate_interfaces(self):
+        self.url = f"{ self.aci }/api/node/class/cnwAggrIf.json"
+        response = requests.request("GET", self.url, cookies = self.cookie, verify=False)
+        print(f"<Aggregate Interfaces code { response.status_code } for { self.url }>")
+        response_dict  = response.json()
+        return(response_dict)
+
+    def l3_interfaces(self):
+        self.url = f"{ self.aci }/api/node/class/l3Inst.json"
+        response = requests.request("GET", self.url, cookies = self.cookie, verify=False)
+        print(f"<L3 Interfaces code { response.status_code } for { self.url }>")
+        response_dict  = response.json()
+        return(response_dict)
+
     def json_file(self, parsed_json):
         if "Tenant" in self.url:
             with open('Tenant/JSON/Tenants.json', 'w' ) as f:
@@ -678,6 +708,18 @@ class ACEye():
             with open('Cluster Health/JSON/Cluster Health.json', 'w' ) as f:
                 f.write(parsed_json)
 
+        if "vnsMDev" in self.url:
+            with open('Device Packages/JSON/Device Packages.json', 'w' ) as f:
+                f.write(parsed_json)
+
+        if "cnwAggrIf" in self.url:
+            with open('Aggregate Interfaces/JSON/Aggregate Interfaces.json', 'w' ) as f:
+                f.write(parsed_json)
+
+        if "l3Inst" in self.url:
+            with open('L3 Interfaces/JSON/L3 Interfaces.json', 'w' ) as f:
+                f.write(parsed_json)
+
     def yaml_file(self, parsed_json):
         clean_yaml = yaml.dump(json.loads(parsed_json), default_flow_style=False)
         if "Tenant" in self.url:
@@ -853,6 +895,18 @@ class ACEye():
             with open('Cluster Health/YAML/Cluster Health.yaml', 'w' ) as f:
                 f.write(clean_yaml)
 
+        if "vnsMDev" in self.url:
+            with open('Device Packages/YAML/Device Packages.yaml', 'w' ) as f:
+                f.write(clean_yaml)
+
+        if "cnwAggrIf" in self.url:
+            with open('Aggregate Interfaces/YAML/Aggregate Interfaces.yaml', 'w' ) as f:
+                f.write(clean_yaml)
+
+        if "l3Inst" in self.url:
+            with open('L3 Interfaces/YAML/L3 Interfaces.yaml', 'w' ) as f:
+                f.write(clean_yaml)
+
     def csv_file(self, parsed_json):
         template_dir = Path(__file__).resolve().parent
         env = Environment(loader=FileSystemLoader(str(template_dir)))
@@ -1032,6 +1086,18 @@ class ACEye():
             with open('Cluster Health/CSV/Cluster Health.csv', 'w' ) as f:
                 f.write(csv_output)
 
+        if "vnsMDev" in self.url:
+            with open('Device Packages/CSV/Device Packages.csv', 'w' ) as f:
+                f.write(csv_output)
+
+        if "cnwAggrIf" in self.url:
+            with open('Aggregate Interfaces/CSV/Aggregate Interfaces.csv', 'w' ) as f:
+                f.write(csv_output)
+
+        if "l3Inst" in self.url:
+            with open('L3 Interfaces/CSV/L3 Interfaces.csv', 'w' ) as f:
+                f.write(csv_output)
+
     def markdown_file(self, parsed_json):
         template_dir = Path(__file__).resolve().parent
         env = Environment(loader=FileSystemLoader(str(template_dir)))
@@ -1212,6 +1278,18 @@ class ACEye():
             with open('Cluster Health/Markdown/Cluster Health.md', 'w' ) as f:
                 f.write(markdown_output)
 
+        if "vnsMDev" in self.url:
+            with open('Device Packages/Markdown/Device Packages.md', 'w' ) as f:
+                f.write(markdown_output)
+
+        if "cnwAggrIf" in self.url:
+            with open('Aggregate Interfaces/Markdown/Aggregate Interfaces.md', 'w' ) as f:
+                f.write(markdown_output)
+
+        if "l3Inst" in self.url:
+            with open('L3 Interfaces/Markdown/L3 Interfaces.md', 'w' ) as f:
+                f.write(markdown_output)
+
     def html_file(self, parsed_json):
         template_dir = Path(__file__).resolve().parent
         env = Environment(loader=FileSystemLoader(str(template_dir)))
@@ -1392,6 +1470,18 @@ class ACEye():
             with open('Cluster Health/HTML/Cluster Health.html', 'w' ) as f:
                 f.write(html_output)
 
+        if "vnsMDev" in self.url:
+            with open('Device Packages/HTML/Device Packages.html', 'w' ) as f:
+                f.write(html_output)
+
+        if "cnwAggrIf" in self.url:
+            with open('Aggregate Interfaces/HTML/Aggregate Interfaces.html', 'w' ) as f:
+                f.write(html_output)
+
+        if "l3Inst" in self.url:
+            with open('L3 Interfaces/HTML/L3 Interfaces.html', 'w' ) as f:
+                f.write(html_output)
+
     def mindmap_file(self, parsed_json):
         template_dir = Path(__file__).resolve().parent
         env = Environment(loader=FileSystemLoader(str(template_dir)))
@@ -1572,6 +1662,18 @@ class ACEye():
             with open('Cluster Health/Mindmap/Cluster Health.md', 'w' ) as f:
                 f.write(mindmap_output)
 
+        if "vnsMDev" in self.url:
+            with open('Device Packages/Mindmap/Device Packages.md', 'w' ) as f:
+                f.write(mindmap_output)
+
+        if "cnwAggrIf" in self.url:
+            with open('Aggregate Interfaces/Mindmap/Aggregate Interfaces.md', 'w' ) as f:
+                f.write(mindmap_output)
+
+        if "l3Inst" in self.url:
+            with open('L3 Interfaces/Mindmap/L3 Interfaces.md', 'w' ) as f:
+                f.write(mindmap_output)
+
     def all_files(self, parsed_json):
         self.json_file(parsed_json)
         self.yaml_file(parsed_json)
